<?php class obox_maps_widget extends WP_Widget {
	/** constructor */
		function __construct() {
			$widget_ops = array( 'classname' => 'obox-maps-widget', 'description' => 'Display a google map on the homepage.' );
			parent::__construct( 'obox_maps_widget', '(Obox) Google Maps Widget', $widget_ops );
    	}
	/** @see WP_Widget::widget */
	function widget( $args, $instance ) {

		// Make sure the correct scripts are active when the widget is active
		global $obox_themeid;
		wp_enqueue_script( $obox_themeid."-map-api","https://maps.googleapis.com/maps/api/js?v=3.exp&sensor=false");
		wp_enqueue_script( $obox_themeid."-map-trigger", get_template_directory_uri()."/scripts/maps.js", array( "jquery" ) );

		extract( $args );

		// Turn $instance array into variables
		$instance_defaults = array ();
		$instance_args = wp_parse_args( $instance, $instance_defaults );
		extract( $instance_args, EXTR_SKIP ); ?>

		<li class="map-widget widget clearfix" id="<?php echo $widget_id; ?>">
			<?php if(isset($title) && $title != "") : ?>
				<h3 class="widgettitle">
					<?php echo $title; ?>
				</h3>
			<?php endif; ?>
			<?php if($map_intro !='' || $address_shown !='') : ?>
				<div class="content clearfix">
					<?php if(isset($map_intro) && $map_intro !='') : ?>
						<p class="widget-intro"><?php echo $map_intro; ?></p>
					<?php endif; ?>
					<?php if(isset($address_shown) && $address_shown !='') : ?>
						<p class="map-address"><?php echo $address_shown; ?></p>
					<?php endif; ?>
				</div>
			<?php endif; ?>
			<div id="map" rel="<?php echo $location; ?>" <?php if($latlong != "") : ?>data-latlong="<?php echo $latlong; ?>"<?php endif; ?>></div>
		</li>

<?php
	}

	/** @see WP_Widget::update */
	function update( $new_instance, $old_instance ) {
		return $new_instance;
	}

	/** @see WP_Widget::form */
	function form($instance) {

		// Turn $instance array into variables
		$instance_defaults = array ('post_count' => 3, 'auto_interval' => '');
		$instance_args = wp_parse_args( $instance, $instance_defaults );
		extract( $instance_args, EXTR_SKIP ); ?>

		<p>
			<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e("Title", "ocmx"); ?>
				<input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php if(isset($title)) echo $title; ?>" />
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('map_intro'); ?>">
				<?php _e("Map Intro", "ocmx"); ?>
				<textarea class="widefat" rows="5" id="<?php echo $this->get_field_id('map_intro'); ?>" name="<?php echo $this->get_field_name('map_intro'); ?>"><?php if(isset($map_intro)) echo $map_intro; ?></textarea>
				<small class="obox-widget-tip">
					<?php _e("Provide some intro text.", "ocmx"); ?>
				</small>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('location'); ?>">
				<?php _e("Google Maps Location", "ocmx"); ?>
				<input class="widefat" id="<?php echo $this->get_field_id('location'); ?>" name="<?php echo $this->get_field_name('location'); ?>" type="text" value="<?php if(isset($location)) echo $location; ?>" />
				<small class="obox-widget-tip">
					<?php _e("Provide a specific address i.e. (79 Sample Road, Cape Town, Western Cape, South Africa) <a target='_blank' href='http://maps.google.com/'>Check on Google Maps</a>.", "ocmx"); ?>
				</small>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('latlong'); ?>">
				<?php _e("Google Maps Latitude & Longitude (Optional)", "ocmx"); ?>
				<input class="widefat" id="<?php echo $this->get_field_id('latlong'); ?>" name="<?php echo $this->get_field_name('latlong'); ?>" type="text" value="<?php if(isset($latlong)) echo $latlong; ?>" />
				<small class="obox-widget-tip">
					<?php _e("Provide specific GPS co-ordinates for Google Maps. Use this if your location does not have a valid Google Maps Location i.e. (-34.397, 150.644)", "ocmx"); ?>
				</small>
			</label>
		</p>

		<p>
			<label for="<?php echo $this->get_field_id('address_shown'); ?>">
				<?php _e("Address Shown", "ocmx"); ?>
				<textarea class="widefat" rows="5" id="<?php echo $this->get_field_id('address_shown'); ?>" name="<?php echo $this->get_field_name('address_shown'); ?>"><?php if(isset($address_shown)) echo $address_shown; ?></textarea>
				<small class="obox-widget-tip">
					<?php _e("Provide an Address shown to the public. <html> allowed.", "ocmx"); ?>
				</small>
			</label>
		</p>
<?php
	} // form

}// class

//This sample widget can then be registered in the widgets_init hook:

// register FooWidget widget
add_action('widgets_init', create_function('', 'return register_widget("obox_maps_widget");'));