<?php
class obox_portfolio_widget extends WP_Widget {
	/** constructor */
		function __construct() {
			$widget_ops = array('classname' => 'obox-portfolio-widget', 'description' => 'Display portfolio content in a multi-column layout on your home page.' );
			parent::__construct( 'obox_portfolio_widget', '(Obox) Portfolio Widget', $widget_ops );
    	}
	/** @see WP_Widget::widget */
	function widget( $args, $instance ) {

		// Turn $args array into variables.
		extract( $args );

		// Turn $instance array into variables
		$instance_defaults = array ( 'post_thumb' => 1, 'post_count' => 4, 'layout_columns' => 2);
		$instance_args = wp_parse_args( $instance, $instance_defaults );
		extract( $instance_args, EXTR_SKIP );


		if(isset($postfilter) && isset($instance[$postfilter]))
			$filterval = esc_attr($instance[$postfilter]);
		else
			$filterval = 0;
		if(isset($instance["post_category"]))
			$use_category = $instance["post_category"];

		if($use_category != "0") :
			$args = array(
				"post_type" => 'portfolio',
				"posts_per_page" => $post_count,
				"tax_query" => array(
					array(
						"taxonomy" => 'portfolio-category',
						"field" => "slug",
						"terms" => $use_category
					)
				)
			);
		else :
			$args = array(
				"post_type" => 'portfolio',
				"posts_per_page" => $post_count,
			);
		endif;


		// Set the post order
		if(isset($post_order_by)) :
			$args['order'] = $post_order;
			$args['orderby'] = $post_order_by;
		endif;

		// Main Post Query
		$loop = new WP_Query($args);

		// Widget Background CSS
		if( isset( $background_image ) ) { $css = obox_widget_generate_css( array( "widget_id" => $widget_id , "input" => $background_image , "type" => "background" ) ); }

		// Widget Title & Excerpt CSS
		if( isset( $text_color ) ) { $title_excerpt_css =  obox_widget_generate_css(
				array(
					"widget_id" => $widget_id ,
					"input" => $text_color ,
					"type" => "color" ,
					"selectors" => array(
						".widgettitle" ,
						".widget-description" ,
						".column .content h4",
						".column .content h4.post-title"
					)
				)
			); } ?>

		<li class="content-widget portfolio-content-widget widget clearfix" id="<?php echo $widget_id; ?>">

			<?php if(isset($title) && $title != "") : ?>
				<h3 class="widgettitle">
					<?php echo $title; ?>
				</h3>
			<?php endif; ?>

			<?php if(isset($widget_description) && $widget_description !='') : ?>
				<p class="widget-description"><?php echo $widget_description; ?></p>
			<?php endif; ?>


			<div class="expand-portfolio no_display" id="expand-<?php echo $widget_id; ?>"></div>

			<ul class="<?php echo $layout_columns; ?>-column content-widget-item portfolio clearfix">

				<?php while ( $loop->have_posts() ) : $loop->the_post();
					global $post;
					if( $layout_columns == "four" ) {
						$width = 300;
						$height = 250;
						$resizer = '4-3-small';
					} elseif($layout_columns == "three") {
						$width = 660;
						$height = 495;
						$resizer = '4-3-medium';
					} else {
						$width = 980;
						$height = 535;
						$resizer = '1-1-medium';
					}

					$link = get_permalink($post->ID);
					$image_args  = array('postid' => $post->ID, 'width' => $width, 'height' => $height, 'hide_href' => false, 'exclude_video' => $post_thumb, 'wrap' => 'div', 'wrap_class' => 'post-image fitvid', 'imglink' => false, 'resizer' => $resizer);
					$image = get_obox_media($image_args); ?>

					<li class="column" data-post-id="<?php echo the_ID(); ?>" data-container-div-id="#<?php echo $widget_id; ?>">
						<?php if($image != "")
							echo $image;
						?>

						<?php if(isset($show_titles) && $show_titles == "on") : ?>
							<div class="content">
								<h4 class="post-title"><a href="#"><?php the_title(); ?></a></h4>
							</div>
						<?php endif; ?>

					</li>
				<?php endwhile; ?>
			</ul>
		</li>

<?php
	}

	/** @see WP_Widget::update */
	function update($new_instance, $old_instance) {
		return $new_instance;
	}

	/** @see WP_Widget::form */
	function form($instance) {

		// Turn $instance array into variables
		$instance_defaults = array ( 'post_thumb' => 1, 'postfilter' => '0', 'post_count' => 4, 'layout_columns' => 2);
		$instance_args = wp_parse_args( $instance, $instance_defaults );
		extract( $instance_args, EXTR_SKIP );

		// Setup the post filter if it's defined
		if(isset($postfilter) && isset($instance[$postfilter]))
			$filterval = esc_attr($instance[$postfilter]);
		else
			$filterval = 0;

		$post_type_args = array("public" => true, "exclude_from_search" => false, "show_ui" => true);
		$post_types = get_post_types( $post_type_args, "objects");
?>

	<p><em><?php _e("Click Save after selecting a filter from each menu to load the next filter", "ocmx"); ?></em></p>

	<p>
		<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e("Title", "ocmx"); ?><input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php if(isset($title)) echo $title; ?>" /></label>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('widget_description'); ?>">
			<?php _e("Description", "ocmx"); ?>
			<textarea class="widefat" rows="5" id="<?php echo $this->get_field_id('widget_description'); ?>" name="<?php echo $this->get_field_name('widget_description'); ?>"><?php if(isset($widget_description)) echo $widget_description; ?></textarea>
		</label>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('post_category'); ?>">Category</label>
		<?php $cat_list = get_terms("portfolio-category", "orderby=count&hide_empty=0");?>

		<select size="1" class="widefat" id="<?php echo $this->get_field_id("post_category"); ?>" name="<?php echo $this->get_field_name("post_category"); ?>">
			<option <?php if($filterval == 0){echo "selected=\"selected\"";} ?> value="0">All</option>
			<?php foreach($cat_list as $tax) :
				$use_value =  $tax->name;
				if($use_value == $post_category)
					{$selected = " selected='selected' ";}
				else
					{$selected = " ";} ?>
				<option <?php echo $selected; ?> value="<?php echo $use_value; ?>"><?php echo $tax->name; ?></option>
			<?php endforeach; ?>
		 </select>
	</p>


	<?php
	// Setup the column layouts
	$layout_options = array('one' => '1', 'two' => '2', 'three' => '3', 'four' => '4');?>
	<p>
		<label for="<?php echo $this->get_field_id('layout_columns'); ?>"><?php _e("Column Layout", "ocmx"); ?></label>
		<select size="1" class="widefat" id="<?php echo $this->get_field_id('layout_columns'); ?>" name="<?php echo $this->get_field_name('layout_columns'); ?>">
			<?php foreach($layout_options as $value => $label) : ?>
				<option <?php if($layout_columns == $value) : ?>selected="selected"<?php endif; ?> value="<?php echo $value; ?>"><?php echo $label; ?></option>
			<?php endforeach; ?>
		</select>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('post_count'); ?>"><?php _e("Post Count", "ocmx"); ?></label>
		<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_count'); ?>" name="<?php echo $this->get_field_name('post_count'); ?>">
			<?php $i = 1;
			while($i < 25) :?>
				<option <?php if($post_count == $i) : ?>selected="selected"<?php endif; ?> value="<?php echo $i; ?>"><?php echo $i; ?></option>
			<?php if($i < 1) :
					$i++;
				else:
					$i=($i+1);
				endif;
			endwhile; ?>
		</select>
	</p>
	<?php  // Setup the order values
	$order_params = array("date" => "Post Date", "title" => "Post Title", "rand" => "Random",  "comment_count" => "Comment Count",  "menu_order" => "Menu Order"); ?>
	<p>
		<label for="<?php echo $this->get_field_id('post_order_by'); ?>"><?php _e("Order By", "ocmx"); ?></label>
		<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_order_by'); ?>" name="<?php echo $this->get_field_name('post_order_by'); ?>">
			<?php foreach($order_params as $value => $label) :?>
				<option  <?php if(isset($post_order_by) && $post_order_by == $value){echo "selected=\"selected\"";} ?> value="<?php echo $value; ?>"><?php echo $label; ?></option>
			<?php endforeach;?>
		</select>
	</p>
	<p>
		<label for="<?php echo $this->get_field_id('post_order'); ?>"><?php _e("Order", "ocmx"); ?></label>
		<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_order'); ?>" name="<?php echo $this->get_field_name('post_order'); ?>">
			<option <?php if(!isset($post_order) || isset($post_order) && $post_order == "DESC") : ?>selected="selected"<?php endif; ?> value="DESC"><?php _e("Descending", 'ocmx'); ?></option>
			<option <?php if(isset($post_order) && $post_order == "ASC") : ?>selected="selected"<?php endif; ?> value="ASC"><?php _e("Ascending", 'ocmx'); ?></option>
		</select>
	</p>


	<p>
		<label for="<?php echo $this->get_field_id('post_thumb'); ?>"><?php _e("Show Images or Videos?", "ocmx"); ?></label>
		<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_thumb'); ?>" name="<?php echo $this->get_field_name('post_thumb'); ?>">
				<option <?php if($post_thumb == "none") : ?>selected="selected"<?php endif; ?> value="none"><?php _e("None", "ocmx"); ?></option>
				<option <?php if($post_thumb == "1") : ?>selected="selected"<?php endif; ?> value="1"><?php _e("Featured Thumbnails", "ocmx"); ?></option>
				<option <?php if($post_thumb == "0") : ?>selected="selected"<?php endif; ?> value="0"><?php _e("Videos", "ocmx"); ?></option>
		</select>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('show_titles'); ?>">
			<input type="checkbox" <?php if(isset($show_titles) && $show_titles == "on") : ?>checked="checked"<?php endif; ?> id="<?php echo $this->get_field_id('show_titles'); ?>" name="<?php echo $this->get_field_name('show_date'); ?>">
			<?php _e("Show Titles", "ocmx"); ?>
		</label>
	</p>

	<hr />
	<h4><?php _e( 'Widget Styling' , 'ocmx' ); ?></h4>

	<p>
		<?php if ( !isset( $background_image ) ) $background_image = 0;

		obox_widget_image_control( 'Background Color &amp; Image' , $this->get_field_name("background_image") , $background_image ); ?>
	</p>
	<p>
		<?php if (! isset( $text_color ) ) $text_color = 0;

		obox_widget_color_control( 'Title &amp; Excerpt Color' , $this->get_field_name("text_color") , $text_color ); ?>
	</p>

<?php
	} // form

}// class

//This sample widget can then be registered in the widgets_init hook:

// register FooWidget widget
add_action('widgets_init', create_function('', 'return register_widget("obox_portfolio_widget");'));

?>